#
# spec file for package python-biplist
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-biplist
Version:        1.0.3
Release:        bp155.2.11
Summary:        A library for reading/writing binary plists
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://bitbucket.org/wooster/biplist
Source:         https://files.pythonhosted.org/packages/source/b/biplist/biplist-%{version}.tar.gz
# Test on 32bit expects long==int which is true only on py3
Patch0:         skip-test.patch
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
biplist is a binary plist parser/generator for Python.

Binary Property List (plist) files provide a faster and smaller serialization
format for property lists on OS X. This is a library for generating binary
plists which can be read by OS X, iOS, or other clients.

%prep
%setup -q -n biplist-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec -m unittest discover -s tests -v

%files %{python_files}
%license LICENSE
%doc AUTHORS README.md
%{python_sitelib}/*

%changelog
* Thu Apr  2 2020 Paolo Stivanin <info@paolostivanin.com>
- Remove nose dep as upstream is using unittest
- Add skip-test.patch to disable a failing test
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue May 22 2018 tchvatal@suse.com
- Disable one test that expect int to be equal to long on 32bit
* Tue May 22 2018 tchvatal@suse.com
- Update to version 1.0.3:
  * Added additional checks to guard against invalid plists. This includes writing and reading plists with recursive collections.
  * Handle OverflowErrors when reading dates outside the range of datetime.datetime
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to version 1.0.2
  * Sort sets and dictionaries by key when writing.
- Update to version 1.0.1
  * Adding back in Python 2.6 support. This will be removed again in a future version.
- Update to version 1.0.0
  * This release changes the type of `Uid` from a subclass of `int` to a subclass of `object`.
  * This change was made to address GitHub issue Ints are being turned into Uids and vice versa when both are present in a plist.
  * This release also bumps the minimum supported Python versions to 2.7 and 3.4.
- Update to version 0.9.1
  * Fixes GitHub issue ERROR: testLargeDates (test_valid.TestValidPlistFile)
  * Fixes Empty Data object converted as empty string
  * Creates 1-byte strings when possible
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Sun Apr 26 2015 benoit.monin@gmx.fr
- update to version 0.9:
  * Fixes #5 ValueError: timestamp out of range for platform time_t
  * Merged pull request #3 removing the `six` module while keeping
    Python3 compatibility
- additional changes from version v0.8:
  * Fixes #3 testFileRead fails using python 3.x along with several
    other Python 3 compatibility issues.
- update project URL
- add fdupes as BuildRequires and call it after install
- set a minimum version to python 2.7
- remove python-six from BuildRequires: now unneeded
- quiet the test run to avoid spamming the build log
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
* Fri Jan 11 2013 p.drouand@gmail.com
- Update to 0.5 version:
  * Fix a bug when writing non-binary (XML) plist with Data values
  * Cleaned up a few stray comments and assertions.
- Add BuildRequires: python-six needed for tests
* Wed Mar 21 2012 saschpe@gmx.de
- Initial version
